@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * $Id: gnome-canvas-text.c,v 1.72 2001/10/05 03:45:56 msw Exp $
+ * $Id: gnome-canvas-text.c,v 1.74 2001/11/19 00:56:37 alexl Exp $
  * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
  * All rights reserved.
  *
@@ -879,13 +879,25 @@ gnome_canvas_text_set_property (GObject            *object,
 	
 
 	if (!text->layout) {
+
 	        PangoContext *gtk_context, *context;
 		gtk_context = gtk_widget_get_pango_context (GTK_WIDGET (item->canvas));
-
 		
 	        if (item->canvas->aa)  {
 			PangoLanguage *language;
-		        context = pango_ft2_get_context ();
+			gint	pixels, mm;
+			double	dpi_x;
+			double	dpi_y;
+			
+			pixels = gdk_screen_width ();
+			mm = gdk_screen_width_mm ();
+			dpi_x = (((double) pixels * 25.4) / (double) mm);
+			
+			pixels = gdk_screen_height ();
+			mm = gdk_screen_height_mm ();
+			dpi_y = (((double) pixels * 25.4) / (double) mm);
+			
+		        context = pango_ft2_get_context (dpi_x, dpi_y);
 			language = pango_context_get_language (gtk_context);
 			pango_context_set_language (context, language);
 			pango_context_set_base_dir (context,
